@@ -7,7 +7,7 @@ from siegfried import (
 
 from libs import feedparser
 from util import (
-  get_jsonpath, strip_tags, parse_datetime, imgs_from_html
+  get_jsonpath, strip_tags, parse_datetime, imgs_from_html, utc_now
   )
 
 try:
@@ -110,7 +110,7 @@ class SupeRSS:
     if len(candidates) > 0:
       return parse_datetime(sorted(candidates)[0])
     else:
-      return datetime.utcnow()
+      return utc_now()
 
 
   # get authors, using `lauteur` for parsing.
