@@ -32,21 +32,17 @@ def utc_now():
   return dt.replace(tzinfo=pytz.utc)
 
 # time obj -> datetime
-def parse_datetime(t, set_as_now = False):
-
-  if set_as_now:
-    return utc_now()
-
-  else:
-    return datetime(
-      year = t.tm_year,
-      month = t.tm_mon,
-      day = t.tm_mday,
-      hour = t.tm_hour,
-      minute = t.tm_min,
-      second = t.tm_sec,
-      tzinfo = pytz.utc
-    )
+def parse_datetime(t):
+  
+  return datetime(
+    year = t.tm_year,
+    month = t.tm_mon,
+    day = t.tm_mday,
+    hour = t.tm_hour,
+    minute = t.tm_min,
+    second = t.tm_sec,
+    tzinfo = pytz.utc
+  )
 
 def get_jsonpath(obj, path, null=[]):
   """
